Name:			supernovas-devel
Version:		1.0.1
Release:		1%{?dist}
Summary:		C development files for the SuperNOVAS C/C++ astronomy library
Group:			Development/Libraries
License:		Unlicense
URL:			https://smithsonian.github.io/SuperNOVAS/
Source0:		https://github.com/Smithsonian/SuperNOVAS/archive/refs/tags/v%{version}.tar.gz
Requires:		supernovas-libs = %{version}-%{release}
BuildRequires:		gcc
BuildRequires:		sed

%description

This package provides C headers and non-versioned shared library symbolic 
links for the SuperNOVAS library.

SuperNOVAS is a C/C++ astronomy software library, providing high-precision 
astronomical calculations such as one might need for running an observatory or 
a precise planetarium program. It is a fork of the Naval Observatory Vector 
Astrometry Software (NOVAS) C version 3.1, providing bug fixes and making it 
easier to use overall.

The main goal of SuperNOVAS is to improve usability, add new features, promote 
best practices, and provide accessible documentation -- all while retaining 
100% API compatibility with NOVAS C 3.1. Thus, if you have written code for 
NOVAS C 3.1, it should readily work with SuperNOVAS also.

SuperNOVAS is entirely free to use without licensing restrictions. Its source 
code is compatible with the C90 standard, and hence should be suitable for old 
and new platforms alike. It is light-weight and easy to use, with full support 
for the IAU 2000/2006 standards for sub-micro-arc-second position calculations

%global debug_package %{nil}

%prep
%setup -q -n SuperNOVAS-%{version}


%build

make README-headless.md

%install
rm -rf %{buildroot}

# C header files
mkdir -p %{buildroot}/%{_prefix}/include
install -m 644 -D include/* %{buildroot}/%{_prefix}/include/

# README, CHANGELOG, and CONTRIBUTING
mv README-headless.md README.md

# Install libsupernovas.so.1 runtime library
mkdir -p %{buildroot}/%{_libdir}

# Install libsupernovas.so.1 runtime library
mkdir -p %{buildroot}/%{_libdir}

# Link libsupernovas.so.1 -> libsupernovas.so
( cd %{buildroot}/%{_libdir} ; ln -sf libsupernovas.so.1 libsupernovas.so )

# Link libsolsys1.so.1 -> libsolsys1.so
( cd %{buildroot}/%{_libdir} ; ln -sf libsolsys1.so.1 libsolsys1.so )

# Link libsolsys2.so.1 -> libsolsys2.so
( cd %{buildroot}/%{_libdir} ; ln -sf libsolsys2.so.1 libsolsys2.so )

# (compat naming) Link libnovas.so -> libsupernovas.so
( cd %{buildroot}/%{_libdir} ; ln -sf libsupernovas.so libnovas.so )

%clean
rm -rf %{buildroot}


%files
%license LICENSE
%doc README.md CHANGELOG.md CONTRIBUTING.md
%{_prefix}/include/*
%{_libdir}/*


%changelog
%autochangelog

